Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(666)

Unified Diff: third_party/WebKit/Source/modules/accessibility/AXLayoutObject.cpp

Issue 2856503003: Nodes with IDs should not be excluded as they might be the target of in-page links and attributes s… (Closed)
Patch Set: Fixed Blink test. Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/accessibility/AXLayoutObject.cpp
diff --git a/third_party/WebKit/Source/modules/accessibility/AXLayoutObject.cpp b/third_party/WebKit/Source/modules/accessibility/AXLayoutObject.cpp
index 721f0d74b304183e7fc4e9d275e7acfbea136764..503fd0b6246f0f7ff909d4accb82335bf27d951f 100644
--- a/third_party/WebKit/Source/modules/accessibility/AXLayoutObject.cpp
+++ b/third_party/WebKit/Source/modules/accessibility/AXLayoutObject.cpp
@@ -298,9 +298,10 @@ AccessibilityRole AXLayoutObject::DetermineAccessibilityRole() {
if (layout_object_->IsLayoutBlockFlow())
return kGroupRole;
- // If the element does not have role, but it has ARIA attributes,
- // accessibility should fallback to exposing it as a group.
- if (SupportsARIAAttributes())
+ // If the element does not have role, but it has ARIA attributes or is an
+ // in-page link target, accessibility should fallback to exposing it as a
+ // group.
+ if (IsInPageLinkTarget() || SupportsARIAAttributes())
return kGroupRole;
return kUnknownRole;

Powered by Google App Engine
This is Rietveld 408576698